@@ -28,20 +28,6 @@ use crate::shipping::ShippingCalculator;
 use crate::shipping::ShippingQuote;
 use crate::transaction::TransactionController;
 
-pub struct MasterContextProvider {
-    db_client: DBClient,
-}
-
-impl MasterContextProvider {
-    pub fn new(db_client: DBClient) -> Self {
-        Self { db_client }
-    }
-
-    pub fn new_context<'a, C: ClientContext>(&'a self, client_ctx: C) -> MasterContext<'a, C> {
-        MasterContext::new(client_ctx, &self.db_client)
-    }
-}
-
 pub struct MasterContext<'a, C: ClientContext> {
     client_ctx: C,
     db_client: &'a DBClient,
